# get-view [![NPM version](https://img.shields.io/npm/v/get-view.svg?style=flat)](https://www.npmjs.com/package/get-view) [![NPM monthly downloads](https://img.shields.io/npm/dm/get-view.svg?style=flat)](https://npmjs.org/package/get-view)  [![NPM total downloads](https://img.shields.io/npm/dt/get-view.svg?style=flat)](https://npmjs.org/package/get-view) [![Linux Build Status](https://img.shields.io/travis/jonschlinkert/get-view.svg?style=flat&label=Travis)](https://travis-ci.org/jonschlinkert/get-view)

> Utility for getting an assemble view from a collection object.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install --save get-view
```

## Usage

Should work with any collection of vinyl files.

```js
var getView = require('get-view');
```

**[templates](https://github.com/jonschlinkert/templates) example**

Given the following setup code, all of the below examples would return a `page` from the `app.views.pages` collection:

```js
var templates = require('templates');
app = templates();
app.create('page');

app.page('foo', {content: 'this is foo'});
app.page('bar.md', {content: 'this is bar'});
app.page('a/b/c/baz.md', {content: 'this is baz', base: 'a'});
app.page('test/fixtures/templates/a.tmpl');
```

Get a view by customizing the lookup key with a function:

```js
var view = getView('foo.md', app.views.pages, function(key) {
  return path.basename(key, path.extname(key));
});

//=> <Page "foo" <Buffer 74 68 69 73 20 69>>
```

Get a view by `view.path`

```js
var view = getView('a/b/c/baz.md', app.views.pages);
//=> <Page "b/c/baz.md" <Buffer 74 68 69 73>>
```

Get a view by `view.basename`

```js
var view = getView('baz.md', app.views.pages);
//=> <Page "b/c/baz.md" <Buffer 74 68 69 73>>
```

Get a view by `view.filename`

```js
var view = getView('baz', app.views.pages);
//=> <Page "b/c/baz.md" <Buffer 74 68 69 73>>
```

Get a view by `view.relative`

```js
var view = getView('b/c/baz.md', app.views.pages);
//=> <Page "b/c/baz.md" <Buffer 74 68 69 73>>
```

## About

### Related projects

* [assemble](https://www.npmjs.com/package/assemble): Get the rocks out of your socks! Assemble makes you fast at creating web projects… [more](https://github.com/assemble/assemble) | [homepage](https://github.com/assemble/assemble "Get the rocks out of your socks! Assemble makes you fast at creating web projects. Assemble is used by thousands of projects for rapid prototyping, creating themes, scaffolds, boilerplates, e-books, UI components, API documentation, blogs, building websit")
* [gulp](https://www.npmjs.com/package/gulp): The streaming build system | [homepage](http://gulpjs.com "The streaming build system")
* [match-file](https://www.npmjs.com/package/match-file): Returns true when the given `name` matches any of the path properties on a vinyl… [more](https://github.com/jonschlinkert/match-file) | [homepage](https://github.com/jonschlinkert/match-file "Returns true when the given `name` matches any of the path properties on a vinyl file.")
* [templates](https://www.npmjs.com/package/templates): System for creating and managing template collections, and rendering templates with any node.js template engine… [more](https://github.com/jonschlinkert/templates) | [homepage](https://github.com/jonschlinkert/templates "System for creating and managing template collections, and rendering templates with any node.js template engine. Can be used as the basis for creating a static site generator or blog framework.")
* [verb](https://www.npmjs.com/package/verb): Documentation generator for GitHub projects. Verb is extremely powerful, easy to use, and is used… [more](https://github.com/verbose/verb) | [homepage](https://github.com/verbose/verb "Documentation generator for GitHub projects. Verb is extremely powerful, easy to use, and is used on hundreds of projects of all sizes to generate everything from API docs to readmes.")
* [vinyl](https://www.npmjs.com/package/vinyl): Virtual file format. | [homepage](https://github.com/gulpjs/vinyl#readme "Virtual file format.")

### Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

### Building docs

_(This project's readme.md is generated by [verb](https://github.com/verbose/verb-generate-readme), please don't edit the readme directly. Any changes to the readme must be made in the [.verb.md](.verb.md) readme template.)_

To generate the readme, run the following command:

```sh
$ npm install -g verbose/verb#dev verb-generate-readme && verb
```

### Running tests

Running and reviewing unit tests is a great way to get familiarized with a library and its API. You can install dependencies and run tests with the following command:

```sh
$ npm install && npm test
```

### Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](https://twitter.com/jonschlinkert)

### License

Copyright © 2017, [Jon Schlinkert](https://github.com/jonschlinkert).
MIT

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.4.2, on February 01, 2017._